<?php
/**
 * Royarch Elementor Global Widget Services_Block8.
 *
 * @package    Royarch - Unikwp
 * @subpackage royarch
 * @since      Royarch 1.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Royarch_Elementor_Global_Widgets_Services_Block8 extends Widget_Base {

	/**
	 * Retrieve Royarch_Elementor_Global_Widgets_Services_Block8 widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Royarch-Global-Widgets-Services-Block8';
	}

	/**
	 * Retrieve Royarch_Elementor_Global_Widgets_Services_Block8 widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Services Block 8', 'royarch' );
	}

	/**
	 * Retrieve royarch_Elementor_Global_Widget_Services_Block8 widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-cogs';
	}

	/**
	 * Retrieve the list of categories the royarch_Elementor_Global_Widget_Services_Block8 widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'royarch-widget-blocks' );
	}
	
	/**
	 * Register royarch_Elementor_Global_Widget_Services_Block8 widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_services_block8_title_manage',
			array(
				'label' => esc_html__( 'Services Block 8', 'royarch' ),
			)
		);
		
		$this->add_control(
		    'widget_number',
		    [
		        'label' => esc_html__( 'Columns Number', 'royarch' ),
                'type' => Controls_Manager::NUMBER,
                'description' => esc_html__('Should be 2,3 or 4 to fit in theme style', 'royarch'),
                'default' => 4,
		    ]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'list_title', [
				'label' => __( 'Services Name', 'royarch' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'list_desc', [
				'label' => __( 'Services Description', 'royarch' ),
				'type' => Controls_Manager::TEXTAREA,
			]
		);

		$repeater->add_control(
			'list_image', [
				'label' => __( 'Services Image', 'royarch' ),
				'type' => Controls_Manager::MEDIA,
			]
		);

		$repeater->add_control(
			'list_icon', [
				'label' => __( 'Icon', 'royarch' ),
				'type' => Controls_Manager::ICONS,
			]
		);

		$repeater->add_control(
			'list_url', [
				'label' => __( 'Link URL', 'royarch' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'list',
			[
				'label' => __( 'Services List', 'royarch' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_title }}}',
			]
		);

		$repeater = new Repeater();
        
		$this->end_controls_section();

	}

	/**
	 * Render Royarch_Elementor_Global_Widgets_Services_Block8 widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
        $settings = $this->get_settings_for_display();?>

        <!-- services-section7 
			================================================== -->
		<section class="services-section8">

			<div class="container">
				<div class="services-box8">
					<div class="row">
						<?php foreach (  $settings['list'] as $item ) { 
							$colNumber = 12/do_shortcode($settings['widget_number']);
							
							?>
                        <div class="col-md-<?php echo esc_attr($colNumber) ?>">
                        	<div class="services-post8">
								<img src="<?php echo esc_url($item['list_image']['url']); ?>" alt>
								<div class="serv-cont">
									<h4><?php echo esc_html($item['list_title']); ?></h4>
									<p><?php echo esc_html($item['list_desc']); ?> </p>
									<a href="<?php echo esc_url($item['list_url']); ?>">
										
										<?php
										if (strpos($item['list_icon']['value'],'fa-') !== false) {
											Icons_Manager::render_icon( $item['list_icon'], [ 'aria-hidden' => 'true' ] );
										} elseif (strpos($item['list_icon']['value'],'material-icons-outlined') !== false) {
											?>
											<span class="<?php echo esc_attr($item['list_icon']['value']); ?>">
											<?php 
												echo esc_html(str_replace( 'material-icons-outlined md-', '', $item['list_icon']['value']  ));
											?>
											</span>
											<?php
										} else { 
											?>
											<span class="<?php echo esc_attr($item['list_icon']['value']); ?>">
											<?php 
												echo esc_html(str_replace( 'material-icons md-', '', $item['list_icon']['value']  ));
											?>
											</span>
											<?php 
										}
										?>
									</a>
								</div>
							</div>
						</div>

                        <?php } ?>
					</div>
				</div>
			</div>

		</section>
		<!-- End services-section7 -->
    
    <?php

	}
}
